.. _narrative-advanced:

Advanced Topics
---------------

.. toctree::
    :maxdepth: 1

    as-a-library
    close-to-anonymous
    default-views
    add-to-edit-interface
    events
    frontpage-different-template
    images
    blobs
    static-resource-management
    understanding-kotti-startup
    sanitizers
